nengo\_spa\.types
=================

.. automodule:: nengo_spa.types
   :show-inheritance:

   .. rubric:: Classes

   .. autosummary::

      Type
      TAnyVocabOfDim
      TVocabulary

   .. rubric:: Functions

   .. autosummary::

      coerce_types
